@@ -273,7 +273,7 @@ class SystemClient:
 
         return response
 
-    def create_relation(self, origin_id: str, target_id: str, abstract_ids: str | list[str], name: str, access_name: str, key: any = None, key_format: Union[FormatType, None] = None, **kwargs):
+    def create_relation(self, origin_id: str, target_id: str, abstract_ids: Union[str, List[str]], name: str, access_name: str, key: any = None, key_format: Union[FormatType, None] = None, **kwargs):
         layer_id = self.__fetch_layer_id(access_name)
 
         if not isinstance(abstract_ids, list):
